from lxml import etree

class OSMStats(object):

    def __init__(self, osm_file):
        self.osm_file = osm_file
        self.xml_data = etree.parse(self.osm_file)
        self.contributors = {}
        self.amenities = {}

    def get_contributors(self):
        if not self.contributors:
            for user in self.xml_data.xpath("//@user"):
                if user in self.contributors.keys():
                    self.contributors[user] += 1
                else:
                    self.contributors[user] = 1
        return self.contributors

    def count_amenity(self, name):
        if name not in self.amenities.keys():
            return len(self.xml_data.xpath("//tag[@v='{}']".format(name)))
        else:
            return self.amenities[name]

    def get_all_amenities(self):
        if not self.amenities:
            for tag in self.xml_data.xpath("//tag[@k='amenity']"):
                if tag.attrib['v'] in self.amenities.keys():
                    self.amenities[tag.attrib['v']] += 1
                else:
                    self.amenities[tag.attrib['v']] = 1
        return self.amenities



from setuptools import setup, find_packages

setup(name='osmstats',
      version='1.0',
      description='Processes OpenStreetMap XML file for deriving statistics',
      author='Prasanna Venkadesh',
      author_email='prasmailme@gmail.com',
      url='https://github.com/PrasannaVenkadesh/osmstats',
      install_requires=['lxml==4.1.1'],
      python_requires='>=2.7',
      packages=find_packages(exclude=['contrib', 'docs', 'tests']),
      classifiers=[
          'Development Status :: 3 - Alpha',
          'Intended Audience :: Developers',
          'Topic :: Scientific/Engineering :: Information Analysis',
          'License :: OSI Approved :: GNU General Public License (GPL)',

          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: Implementation :: CPython'
      ],
)
